Package: ggsql
Title: Grammar of Graphics for SQL
Version: 0.3.3
Authors@R: c(
    person("Thomas Lin", "Pedersen", , "thomas.pedersen@posit.co",
           role = c("aut", "cre"), comment = c(ORCID = "0000-0002-5147-4711")),
    person("George", "Stagg", , "george.stagg@posit.co", role = "aut",
           comment = c(ORCID = "0009-0006-3173-9846")),
    person("Teun", "van den Brand", , "teun.vandenbrand@posit.co", role = "aut",
           comment = c(ORCID = "0000-0002-9335-7468")),
    person("Posit, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: Allows you to write queries that combine SQL (Structured Query
  Language) data retrieval with visualization specifications in a single,
  composable syntax. The 'ggsql' package binds directly with the 'ggsql' 'Rust'
  library and allows you to set up readers and writers and execute queries
  against it. The package also offers 'knitr' and 'shiny' integration allowing
  the user to use 'ggsql' in both frameworks.
License: MIT + file LICENSE
Encoding: UTF-8
SystemRequirements: Cargo (Rust's package manager), rustc (>= 1.86),
        ODBC driver manager (unixODBC on Linux, iODBC or unixODBC on
        macOS; built into Windows)
RoxygenNote: 7.3.3
Imports: cli, htmltools, htmlwidgets, jsonlite, knitr, nanoarrow, R6,
        rlang (>= 1.1.0), yaml
Suggests: gapminder, quarto, reticulate, rmarkdown, rsvg, shiny,
        testthat (>= 3.0.0), V8, withr
Config/testthat/edition: 3
Config/rextendr/version: 0.4.2.9000
Depends: R (>= 4.2)
VignetteBuilder: quarto
URL: https://r.ggsql.org, https://github.com/posit-dev/ggsql-r
Config/Needs/website: tidyverse/tidytemplate
Config/Needs/js: node
BugReports: https://github.com/posit-dev/ggsql-r/issues
NeedsCompilation: yes
Packaged: 2026-06-02 13:32:14 UTC; thomas
Author: Thomas Lin Pedersen [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-5147-4711>),
  George Stagg [aut] (ORCID: <https://orcid.org/0009-0006-3173-9846>),
  Teun van den Brand [aut] (ORCID:
    <https://orcid.org/0000-0002-9335-7468>),
  Posit, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Thomas Lin Pedersen <thomas.pedersen@posit.co>
Repository: CRAN
Date/Publication: 2026-06-03 08:20:23 UTC
