# Generated by roxygen2: do not edit by hand

S3method("$",GgsqlReader)
S3method("$",GgsqlSpec)
S3method("$",GgsqlWriter)
S3method("$",ggsql_tables)
S3method("[[",GgsqlReader)
S3method("[[",GgsqlSpec)
S3method("[[",GgsqlWriter)
S3method("[[",ggsql_tables)
S3method(knit_print,Spec)
S3method(names,ggsql_tables)
S3method(print,ggsql_tables)
S3method(print,ggsql_validated)
S3method(str,Spec)
export(custom_reader)
export(duckdb_reader)
export(ggsqlOutput)
export(ggsql_execute)
export(ggsql_execute_sql)
export(ggsql_has_visual)
export(ggsql_is_valid)
export(ggsql_layer_count)
export(ggsql_layer_data)
export(ggsql_layer_sql)
export(ggsql_metadata)
export(ggsql_register)
export(ggsql_render)
export(ggsql_save)
export(ggsql_session_reader)
export(ggsql_sql)
export(ggsql_stat_data)
export(ggsql_stat_sql)
export(ggsql_table)
export(ggsql_table_names)
export(ggsql_unregister)
export(ggsql_validate)
export(ggsql_visual)
export(ggsql_warnings)
export(odbc_reader)
export(renderGgsql)
export(snowflake_reader)
export(vegalite_writer)
import(rlang)
importFrom(R6,R6Class)
importFrom(knitr,knit_print)
importFrom(utils,str)
useDynLib(ggsql, .registration = TRUE)
