# Generated by extendr: Do not edit by hand

# nolint start

#
# This file was created with the following call:
#   .Call("wrap__make_ggsql_wrappers", use_symbols = TRUE, package_name = "ggsql")

#' @usage NULL
#' @useDynLib ggsql, .registration = TRUE
NULL

ggsql_validate_impl <- function(query) .Call(wrap__ggsql_validate_impl, query)

ggsql_version_impl <- function() .Call(wrap__ggsql_version_impl)

GgsqlReader <- new.env(parent = emptyenv())

GgsqlReader$new <- function(connection) .Call(wrap__GgsqlReader__new, connection)

GgsqlReader$new_custom <- function(execute_sql, register, unregister) .Call(wrap__GgsqlReader__new_custom, execute_sql, register, unregister)

GgsqlReader$register_ipc <- function(name, ipc_bytes, replace) invisible(.Call(wrap__GgsqlReader__register_ipc, self, name, ipc_bytes, replace))

GgsqlReader$unregister <- function(name) invisible(.Call(wrap__GgsqlReader__unregister, self, name))

GgsqlReader$execute_sql_ipc <- function(sql) .Call(wrap__GgsqlReader__execute_sql_ipc, self, sql)

GgsqlReader$execute <- function(query) .Call(wrap__GgsqlReader__execute, self, query)

#' @export
`$.GgsqlReader` <- function (self, name) { func <- GgsqlReader[[name]]; environment(func) <- environment(); func }

#' @export
`[[.GgsqlReader` <- `$.GgsqlReader`

GgsqlSpec <- new.env(parent = emptyenv())

GgsqlSpec$metadata_rows <- function() .Call(wrap__GgsqlSpec__metadata_rows, self)

GgsqlSpec$metadata_columns <- function() .Call(wrap__GgsqlSpec__metadata_columns, self)

GgsqlSpec$metadata_layer_count <- function() .Call(wrap__GgsqlSpec__metadata_layer_count, self)

GgsqlSpec$get_sql <- function() .Call(wrap__GgsqlSpec__get_sql, self)

GgsqlSpec$get_visual <- function() .Call(wrap__GgsqlSpec__get_visual, self)

GgsqlSpec$layer_count <- function() .Call(wrap__GgsqlSpec__layer_count, self)

GgsqlSpec$layer_data_ipc <- function(index) .Call(wrap__GgsqlSpec__layer_data_ipc, self, index)

GgsqlSpec$stat_data_ipc <- function(index) .Call(wrap__GgsqlSpec__stat_data_ipc, self, index)

GgsqlSpec$get_layer_sql <- function(index) .Call(wrap__GgsqlSpec__get_layer_sql, self, index)

GgsqlSpec$get_stat_sql <- function(index) .Call(wrap__GgsqlSpec__get_stat_sql, self, index)

GgsqlSpec$warnings_json <- function() .Call(wrap__GgsqlSpec__warnings_json, self)

#' @export
`$.GgsqlSpec` <- function (self, name) { func <- GgsqlSpec[[name]]; environment(func) <- environment(); func }

#' @export
`[[.GgsqlSpec` <- `$.GgsqlSpec`

GgsqlWriter <- new.env(parent = emptyenv())

GgsqlWriter$new <- function() .Call(wrap__GgsqlWriter__new)

GgsqlWriter$render <- function(spec) .Call(wrap__GgsqlWriter__render, self, spec)

#' @export
`$.GgsqlWriter` <- function (self, name) { func <- GgsqlWriter[[name]]; environment(func) <- environment(); func }

#' @export
`[[.GgsqlWriter` <- `$.GgsqlWriter`


# nolint end
