# AUTO-GENERATED by tools/update-vega.sh — do not edit by hand.
# To update, change the version variables in tools/update-vega.sh and rerun it.

vega_version <- "6.2.0"
vega_lite_version <- "6.4.2"
vega_embed_version <- "7.1.0"
